@@ -16,6 +16,7 @@ from .optionals import FilesCompleterMethod, get_config_read_mode
 from .type_checking import ArgumentParser, _ArgumentGroup
 from .typing import get_import_path, path_type
 from .util import (
+    default_config_option_help,
     DirectedGraph,
     ParserError,
     import_object,
@@ -280,7 +281,8 @@ class _ActionConfigLoad(Action):
             self._basetype = basetype
         else:
             self.basetype = kwargs.pop('_basetype', None)
-            kwargs['help'] = SUPPRESS
+            kwargs['metavar'] = 'CONFIG'
+            kwargs['help'] = default_config_option_help
             kwargs['default'] = SUPPRESS
             super().__init__(**kwargs)
 
@@ -362,13 +364,16 @@ class _ActionHelpClassPath(_ActionHelpClass):
         })
 
     def print_help(self, call_args, baseclass, dest):
-        val_class = import_object(call_args[2])
+        try:
+            val_class = import_object(call_args[2])
+        except Exception as ex:
+            raise TypeError(f'{call_args[3]}: {ex}')
         if getattr(self._baseclass, '__origin__', None) == Union:
             baseclasses = self._baseclass.__args__
         else:
             baseclasses = [baseclass]
         if not any(_issubclass(val_class, b) for b in baseclasses):
-            raise TypeError(f'Class "{call_args[2]}" is not a subclass of {self._basename}')
+            raise TypeError(f'{call_args[3]}: Class "{call_args[2]}" is not a subclass of {self._basename}')
         super().print_help(call_args, val_class, dest+'.init_args')
 
 
@@ -748,7 +753,20 @@ class ActionParser:
         return base_action_group
 
 
-single_subcommand = ContextVar('single_subcommand', default=True)
+single_subcommand: ContextVar = ContextVar('single_subcommand', default=True)
+
+parent_parsers: ContextVar = ContextVar('parent_parsers', default=[])
+
+
+@contextmanager
+def parent_parsers_context(key, parser):
+    prev = parent_parsers.get()
+    curr = prev + [(key, parser)]
+    t = parent_parsers.set(curr)
+    try:
+        yield
+    finally:
+        parent_parsers.reset(t)
 
 
 class _ActionSubCommands(_SubParsersAction):
@@ -902,19 +920,20 @@ class _ActionSubCommands(_SubParsersAction):
         for subcommand, subparser in zip(subcommands, subparsers):
             # Merge environment variable values and default values
             subnamespace = None
-            if env:
-                subnamespace = subparser.parse_env(defaults=defaults, _skip_check=True)
-            elif defaults:
-                subnamespace = subparser.get_defaults(skip_check=True)
+            key = prefix + subcommand
+            with parent_parsers_context(key, parser):
+                if env:
+                    subnamespace = subparser.parse_env(defaults=defaults, _skip_check=True)
+                elif defaults:
+                    subnamespace = subparser.get_defaults(skip_check=True)
 
             # Update all subcommand settings
             if subnamespace is not None:
-                cfg[prefix+subcommand] = subparser.merge_config(cfg.get(prefix+subcommand, Namespace()), subnamespace)
+                cfg[key] = subparser.merge_config(cfg.get(key, Namespace()), subnamespace)
 
             # Handle inner subcommands
             if subparser._subparsers is not None:
-                prefix = prefix + subcommand + '.'
-                _ActionSubCommands.handle_subcommands(subparser, cfg, env, defaults, prefix, fail_no_subcommand=fail_no_subcommand)
+                _ActionSubCommands.handle_subcommands(subparser, cfg, env, defaults, key+'.', fail_no_subcommand=fail_no_subcommand)
 
 
 class ActionPathList(Action, FilesCompleterMethod):
