@@ -5,6 +5,7 @@ from typing import Any, Callable, Dict, List, Optional, Type, Union
 from .actions import ActionConfigFile
 from .core import ArgumentParser
 from .optionals import docstring_parser_support, import_docstring_parse
+from .util import default_config_option_help
 
 
 __all__ = ['CLI']
@@ -13,7 +14,7 @@ __all__ = ['CLI']
 def CLI(
     components: Union[Callable, Type, List[Union[Callable, Type]]] = None,
     args: List[str] = None,
-    config_help: str = 'Path to a configuration file in json or yaml format.',
+    config_help: str = default_config_option_help,
     set_defaults: Optional[Dict[str, Any]] = None,
     as_positional: bool = True,
     return_parser: bool = False,
@@ -41,7 +42,7 @@ def CLI(
     """
     caller = inspect.stack()[1][0]
     if 'description' not in kwargs:
-        kwargs['description'] = caller.f_globals['__doc__']
+        kwargs['description'] = caller.f_globals.get('__doc__')
 
     if components is None:
         module = inspect.getmodule(caller).__name__  # type: ignore
@@ -56,7 +57,7 @@ def CLI(
     elif not isinstance(components, list):
         components = [components]
 
-    parser = ArgumentParser(parse_as_dict=True, default_meta=False, **kwargs)
+    parser = ArgumentParser(default_meta=False, **kwargs)
     parser.add_argument('--config', action=ActionConfigFile, help=config_help)
 
     if len(components) == 1:
@@ -66,25 +67,27 @@ def CLI(
             parser.set_defaults(set_defaults)
         if return_parser:
             return parser
-        cfg = parser.instantiate_subclasses(parser.parse_args(args))
-        return _run_component(component, cfg)
+        cfg = parser.parse_args(args)
+        cfg_init = parser.instantiate_classes(cfg)
+        return _run_component(component, cfg_init)
 
     subcommands = parser.add_subcommands(required=True)
     comp_dict = {c.__name__: c for c in components}
     for name, component in comp_dict.items():
         subparser = ArgumentParser()
         subparser.add_argument('--config', action=ActionConfigFile, help=config_help)
-        subcommands.add_subcommand(name, subparser, help=_get_help_str(component))  # type: ignore
+        subcommands.add_subcommand(name, subparser, help=_get_help_str(component))
         _add_component_to_parser(component, subparser, as_positional, config_help)
 
     if set_defaults is not None:
         parser.set_defaults(set_defaults)
     if return_parser:
         return parser
-    cfg = parser.instantiate_subclasses(parser.parse_args(args))
-    subcommand = cfg.pop('subcommand')
+    cfg = parser.parse_args(args)
+    cfg_init = parser.instantiate_classes(cfg)
+    subcommand = cfg_init.pop('subcommand')
     component = comp_dict[subcommand]
-    return _run_component(component, cfg.get(subcommand))
+    return _run_component(component, cfg_init.get(subcommand))
 
 
 def _get_help_str(component):
