@@ -7,12 +7,11 @@ import logging
 import os
 import re
 import sys
-from contextlib import redirect_stderr
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, NoReturn, Optional, Sequence, Set, Tuple, Type, Union
 from unittest.mock import patch
 
-from .formatters import DefaultHelpFormatter, empty_help
+from .formatters import DefaultHelpFormatter, empty_help, formatter_context, get_env_var
 from .jsonnet import ActionJsonnet
 from .jsonschema import ActionJsonSchema
 from .loaders_dumpers import check_valid_dump_format, dump_using_format, get_loader_exceptions, loaders, load_value, load_value_context
@@ -33,6 +32,7 @@ from .actions import (
     _find_parent_action_and_subcommand,
     _is_action_value_list,
     filter_default_actions,
+    parent_parsers,
 )
 from .optionals import (
     argcomplete_support,
@@ -44,12 +44,12 @@ from .optionals import (
     import_fsspec,
 )
 from .util import (
+    identity,
     ParserError,
     usage_and_exit_error_handler,
     change_to_path_dir,
     Path,
     LoggerProperty,
-    _get_env_var,
     _suppress_stderr,
     _lenient_check_context,
     lenient_check,
@@ -67,6 +67,7 @@ class _ActionsContainer(SignatureArguments, argparse._ActionsContainer, LoggerPr
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.register('type', None, identity)
         self.register('action', 'parsers', _ActionSubCommands)
 
 
@@ -182,30 +183,21 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
             default_env: Set the default value on whether to parse environment variables.
             default_meta: Set the default value on whether to include metadata in config objects.
         """
-        class FormatterClass(formatter_class):  # type: ignore
-            _parser = self
-
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, formatter_class=formatter_class, **kwargs)
         if self.groups is None:
             self.groups = {}
         self.required_args: Set[str] = set()
         self.save_path_content: Set[str] = set()
-        self._stderr = sys.stderr
         self.default_config_files = default_config_files
         self.default_meta = default_meta
         self.default_env = default_env
         self.env_prefix = env_prefix
-        self.formatter_class = FormatterClass
         self.parser_mode = parser_mode
         self.logger = logger
         self.error_handler = error_handler
         self._print_config = print_config
         if version is not None:
             self.add_argument('--version', action='version', version='%(prog)s '+version, help='Print version and exit.')
-        if parser_mode not in loaders:
-            raise ValueError(f'The only accepted values for parser_mode are {set(loaders.keys())}.')
-        if parser_mode == 'jsonnet':
-            import_jsonnet('parser_mode=jsonnet')
 
 
     ## Parsing methods ##
@@ -414,11 +406,11 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         cfg = Namespace()
         actions = filter_default_actions(self._actions)
         for action in actions:
-            env_var = _get_env_var(self, action)
+            env_var = get_env_var(self, action)
             if env_var in env and isinstance(action, ActionConfigFile):
                 ActionConfigFile.apply_config(self, cfg, action.dest, env[env_var])
         for action in actions:
-            env_var = _get_env_var(self, action)
+            env_var = get_env_var(self, action)
             if env_var in env and isinstance(action, _ActionSubCommands):
                 env_val = env[env_var]
                 if env_val in action.choices:
@@ -427,7 +419,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
                     for k, v in vars(pcfg).items():
                         cfg[subcommand+'.'+k] = v
         for action in actions:
-            env_var = _get_env_var(self, action)
+            env_var = get_env_var(self, action)
             if env_var in env and not isinstance(action, ActionConfigFile):
                 env_val = env[env_var]
                 if _is_action_value_list(action):
@@ -516,7 +508,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         with change_to_path_dir(fpath):
             cfg_str = fpath.get_content()
             parsed_cfg = self.parse_string(cfg_str,
-                                           cfg_path,
+                                           os.path.basename(cfg_path),
                                            ext_vars,
                                            env,
                                            defaults,
@@ -719,7 +711,8 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         with load_value_context(self.parser_mode):
             cleanup_actions(cfg, self._actions)
 
-        return dump_using_format(self, cfg.as_dict(), 'yaml_comments' if yaml_comments else format)
+        with formatter_context(self):
+            return dump_using_format(self, cfg.as_dict(), 'yaml_comments' if yaml_comments else format)
 
 
     def save(
@@ -810,7 +803,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
                             f.write(val.get_content())
                         cfg[key] = type(val)(str(val_path))
 
-            with change_to_path_dir(path_fc):
+            with change_to_path_dir(path_fc), formatter_context(self):
                 save_paths(cfg)
             dump_kwargs['skip_check'] = True
             with open(path_fc(), 'w') as f:
@@ -843,13 +836,21 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
             self.set_defaults(kwargs)
 
 
-    def _get_default_config_files(self) -> List[Path]:
-        default_config_files: List[Path] = []
+    def _get_default_config_files(self) -> List[Tuple[Optional[str], Path]]:
+        default_config_files = []
+
+        for key, parser in parent_parsers.get():
+            for pattern in parser.default_config_files:
+                files = sorted(glob.glob(os.path.expanduser(pattern)))
+                default_config_files += [(key, v) for v in files]
+
         for pattern in self.default_config_files:
-            default_config_files += sorted(glob.glob(os.path.expanduser(pattern)))
+            files = sorted(glob.glob(os.path.expanduser(pattern)))
+            default_config_files += [(None, x) for x in files]
+
         if len(default_config_files) > 0:
             try:
-                return [Path(x, mode=get_config_read_mode()) for x in default_config_files]
+                return [(k, Path(v, mode=get_config_read_mode())) for k, v in default_config_files]
             except TypeError:
                 pass
         return []
@@ -900,9 +901,11 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         self._logger.info('Loaded default values from parser.')
 
         default_config_files = self._get_default_config_files()
-        for default_config_file in default_config_files:
+        for key, default_config_file in default_config_files:
             with change_to_path_dir(default_config_file), load_value_context(self.parser_mode):
                 cfg_file = self._load_config_parser_mode(default_config_file.get_content())
+                if key is not None:
+                    cfg_file = cfg_file.get(key)
                 try:
                     self.print_config_skip = True
                     cfg_file = self._parse_common(
@@ -937,7 +940,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         """Logs error message if a logger is set, calls the error handler and raises a ParserError."""
         self._logger.error(message)
         if self._error_handler is not None:
-            with redirect_stderr(self._stderr):
+            with _suppress_stderr():
                 self._error_handler(self, message)
         if ex is None:
             raise ParserError(message)
@@ -1110,6 +1113,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
 
 
     def format_help(self) -> str:
+        defaults = None
         if len(self._default_config_files) > 0:
             note = 'no existing default config file found.'
             try:
@@ -1119,13 +1123,12 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
                     if isinstance(config_files, list):
                         config_files = [str(x) for x in config_files]
                     note = f'default values below are the ones overridden by the contents of: {config_files}'
-                    self.formatter_class.defaults = defaults
             except ParserError as ex:
                 note = f'tried getting defaults considering default_config_files but failed due to: {ex}'
             group = self._default_config_files_group
             group.description = f'{self._default_config_files}, Note: {note}'
-        help_str = super().format_help()
-        self.formatter_class.defaults = None
+        with formatter_context(self, defaults):
+            help_str = super().format_help()
         return help_str
 
 
@@ -1354,6 +1357,31 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
             raise ValueError('env_prefix has to be a string or None.')
 
 
+    @property
+    def parser_mode(self) -> str:
+        """Mode for parsing configuration files: ``'yaml'``, ``'jsonnet'`` or ones added via :func:`.set_loader`.
+
+        :getter: Returns the current parser mode.
+        :setter: Sets the parser mode.
+
+        Raises:
+            ValueError: If an invalid value is given.
+        """
+        return self._parser_mode
+
+
+    @parser_mode.setter
+    def parser_mode(self, parser_mode: str):
+        if parser_mode not in loaders:
+            raise ValueError(f'The only accepted values for parser_mode are {set(loaders.keys())}.')
+        if parser_mode == 'jsonnet':
+            import_jsonnet('parser_mode=jsonnet')
+        self._parser_mode = parser_mode
+        if self._subparsers:
+            for subparser in self._subcommands_action._name_parser_map.values():
+                subparser.parser_mode = parser_mode  # type: ignore
+
+
 if omegaconf_support:
     from .loaders_dumpers import set_loader
     from .optionals import get_omegaconf_loader
