@@ -7,7 +7,6 @@ import re
 import stat
 import sys
 import warnings
-from argparse import Action
 from collections import defaultdict
 from contextlib import contextmanager, redirect_stderr
 from contextvars import ContextVar
@@ -34,13 +33,17 @@ __all__ = [
 ]
 
 
-null_logger = logging.Logger('jsonargparse_null_logger')
+null_logger = logging.getLogger('jsonargparse_null_logger')
 null_logger.addHandler(logging.NullHandler())
+null_logger.parent = None
 
 
 NoneType = type(None)
 
 
+default_config_option_help = 'Path to a configuration file.'
+
+
 class ParserError(Exception):
     """Error raised when parsing a value fails."""
     pass
@@ -58,6 +61,10 @@ def warning(message, category=JsonargparseWarning, stacklevel=1):
     )
 
 
+def identity(value):
+    return value
+
+
 def _parse_value_or_config(value: Any, enable_path: bool = True) -> Tuple[Any, Optional['Path']]:
     """Parses yaml/json config in a string or a path"""
     cfg_path = None
@@ -90,15 +97,6 @@ def usage_and_exit_error_handler(parser: 'ArgumentParser', message: str) -> None
     parser.exit(2)
 
 
-def _get_env_var(parser: 'ArgumentParser', action: 'Action') -> str:
-    """Returns the environment variable for a given parser and action."""
-    if hasattr(parser, '_parser'):
-        parser = parser._parser
-    env_var = (parser._env_prefix+'_' if parser._env_prefix else '') + action.dest
-    env_var = env_var.replace('.', '__').upper()
-    return env_var
-
-
 def _issubclass(cls, class_or_tuple):
     """Extension of issubclass that supports non-class argument."""
     return inspect.isclass(cls) and issubclass(cls, class_or_tuple)
@@ -107,10 +105,18 @@ def _issubclass(cls, class_or_tuple):
 def import_object(name: str):
     """Returns an object in a module given its dot import path."""
     if not isinstance(name, str) or '.' not in name:
-        raise ValueError('Expected a dot import path string')
+        raise ValueError(f'Expected a dot import path string: {name}')
+    if not all(x.isidentifier() for x in name.split('.')):
+        raise ValueError(f'Unexpected import path format: {name}')
     name_module, name_object = name.rsplit('.', 1)
-    module = __import__(name_module, fromlist=[name_object])
-    return getattr(module, name_object)
+    try:
+        parent = __import__(name_module, fromlist=[name_object])
+    except ModuleNotFoundError as ex:
+        if '.' not in name_module:
+            raise ex
+        name_module, name_object1 = name_module.rsplit('.', 1)
+        parent = getattr(__import__(name_module, fromlist=[name_object1]), name_object1)
+    return getattr(parent, name_object)
 
 
 lenient_check: ContextVar = ContextVar('lenient_check', default=False)
