@@ -3,7 +3,9 @@
 import calendar
 import json
 import os
+import pickle
 import platform
+import sys
 import unittest
 import warnings
 import yaml
@@ -1077,5 +1079,12 @@ class OtherTests(unittest.TestCase):
         self.assertRaises(ParserError, lambda: parser.parse_args([{}]))
 
 
+    @unittest.skipIf(sys.version_info[:2] == (3, 6), 'loggers not pickleable in python 3.6')
+    def test_pickle_parser(self):
+        parser1 = example_parser()
+        parser2 = pickle.loads(pickle.dumps(parser1))
+        self.assertEqual(parser1.get_defaults(), parser2.get_defaults())
+
+
 if __name__ == '__main__':
     unittest.main(verbosity=2)
