@@ -241,6 +241,23 @@ class SignaturesTests(unittest.TestCase):
                 self.assertNotEqual(key.split('.')[1]+' description', _find_action(parser, key).help)
 
 
+    def test_add_method_arguments_parent_classes(self):
+        class MyClass:
+            def mymethod(self, p1: str = '1'):
+                return p1
+
+        class MySubClass(MyClass):
+            def mymethod(self, *args, p2: int = 2, **kwargs):
+                p1 = super().mymethod(**kwargs)
+                return p1, p2
+
+        parser = ArgumentParser()
+        added_args = parser.add_method_arguments(MySubClass, 'mymethod', 'm')
+
+        self.assertIn('m', parser.groups)
+        self.assertEqual(set(added_args), {'m.p1', 'm.p2'})
+
+
     def test_add_function_arguments(self):
 
         def func(a1 = '1',
@@ -300,6 +317,7 @@ class SignaturesTests(unittest.TestCase):
         self.assertRaises(ParserError, lambda: parser.parse_args(['--cal={"class_path":"not.exist.Class"}']))
         self.assertRaises(ParserError, lambda: parser.parse_args(['--cal={"class_path":"calendar.January"}']))
         self.assertRaises(ParserError, lambda: parser.parse_args(['--cal.help=calendar.January']))
+        self.assertRaises(ParserError, lambda: parser.parse_args(['--cal.help=calendar.does_not_exist']))
         self.assertRaises(ValueError, lambda: parser.add_subclass_arguments(calendar.January, 'jan'))
 
         out = StringIO()
@@ -1369,6 +1387,32 @@ class SignaturesConfigTests(TempDirTestCase):
             self.assertEqual(cfg.model.as_dict(), expected)
 
 
+    def test_parent_parser_default_config_files_lightning_issue_11622(self):
+        # https://github.com/PyTorchLightning/pytorch-lightning/issues/11622
+
+        with open('default.yaml', 'w') as f:
+            f.write('fit:\n  model:\n    foo: 123')
+
+        class Foo:
+            def __init__(self, foo: int):
+                self.foo = foo
+
+        parser = ArgumentParser(default_config_files=["default.yaml"], error_handler=None)
+        parser.add_argument('--config', action=ActionConfigFile)
+        subcommands = parser.add_subcommands()
+
+        subparser = ArgumentParser()
+        subparser.add_class_arguments(Foo, nested_key="model")
+        subcommands.add_subcommand("fit", subparser)
+
+        subparser = ArgumentParser()
+        subparser.add_class_arguments(Foo, nested_key="model")
+        subcommands.add_subcommand("test", subparser)
+
+        cfg = parser.parse_args(['fit'])
+        self.assertEqual(cfg.fit.model.foo, 123)
+
+
 @unittest.skipIf(not dataclasses_support, 'dataclasses package is required')
 class DataclassesTests(unittest.TestCase):
 
